using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Domain;
using CommonEntity;

namespace Dao
{
    public interface ISysHotelRepository : IRepository<SysHotel>
	{
        IQueryable<SysHotel> LoadAllByPage(out long total, int page, int rows, string order, string sort, string query, int? groupId);

        SysHotel GetByCode(string code);

        SysHotel GetByAssociatedAccount(string associatedAccount);

        SysHotel GetByDomainUrl(string domainUrl);

        SysHotel GetByETV_HotelId(string hotelid);

        IList<SysHotel> GetByGroup(SysHotelGroup group);

        List<KongQi> GetNeedData();

        List<SomeDeviceExistsData> IsExistsSomeDeviceRoomModal(int id, string roomnum, string start_address, string end_address);

        List<SysHotel> get_fcs_hotels();
	}
}
